package com.perforce.hwsclient;

import retrofit.Callback;
import retrofit.http.*;

import com.perforce.hwsclient.models.CommandResponse;
import com.perforce.hwsclient.models.ChangelistRequest;
import com.perforce.hwsclient.models.GitFusionRepoId;
import com.perforce.hwsclient.models.GitFusionRepoConfig;

    import java.util.ArrayList;
    import java.util.HashMap;
    import java.util.List;
    import java.util.Map;

    public interface AlphaApi {
    
        /**
        * 
        * Sync method
        * Create a new changelist that can affect multiple files using different kinds of actions.\nIf you require the ability to integrate or move, for example, you can use this method.
           * @param server The server ID that we execute this particular method against.
           * @param changelistRequest Description of changes to make
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/changes")
        CommandResponse addChange(
        @Path("server") String server, @Body ChangelistRequest changelistRequest
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param changelistRequest Description of changes to make
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/changes")
        void addChange(
        @Path("server") String server, @Body ChangelistRequest changelistRequest, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists all configured repositories readable by the current user.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;GitFusionRepoId&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/git-fusion-repos")
        List<GitFusionRepoId> getGitFusionRepos(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/git-fusion-repos")
        void getGitFusionRepos(
        @Path("server") String server, Callback<List<GitFusionRepoId>> cb
            );
    
        /**
        * 
        * Sync method
        * Submits a [p4gf_config](http://www.perforce.com/perforce/r15.1/manuals/git-fusion/chapter_dyn_ngj_3l.html#section_jgz_nz2_2j) file to create or update a repository configuration.\n\nIf the repository does not exist or has been previously deleted, this method saves contents of the config file to a new `p4gf_config` file.\nIf the repository has already been initialised, this method replaces all of the file contents of the specified repository&#39;s `p4gf_config` file.
           * @param server The server ID that we execute this particular method against.
           * @param body The new configuration
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/git-fusion-repos")
        CommandResponse addGitFusionRepo(
        @Path("server") String server, @Body GitFusionRepoConfig body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param body The new configuration
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/git-fusion-repos")
        void addGitFusionRepo(
        @Path("server") String server, @Body GitFusionRepoConfig body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Return configuration for the specified repository.\nGrabs and returns contents of the [p4gf_config](http://www.perforce.com/perforce/r15.1/manuals/git-fusion/chapter_dyn_ngj_3l.html#section_jgz_nz2_2j) file for given repository.
           * @param server The server ID that we execute this particular method against.
           * @param repo The Git Fusion Repo ID
           * @return GitFusionRepoConfig}
        */
        
        @GET("/p4d/v16.1/{server}/git-fusion-repos/{repo}")
        GitFusionRepoConfig getGitFusionRepo(
        @Path("server") String server, @Path("repo") String repo
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param repo The Git Fusion Repo ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/git-fusion-repos/{repo}")
        void getGitFusionRepo(
        @Path("server") String server, @Path("repo") String repo, Callback<GitFusionRepoConfig> cb
            );
    
        /**
        * 
        * Sync method
        * Deletes the repository configuration (The [p4gf_config file](http://www.perforce.com/perforce/r15.1/manuals/git-fusion/chapter_dyn_ngj_3l.html#section_jgz_nz2_2j)).\nContents of the repository are not deleted from Perforce.
           * @param server The server ID that we execute this particular method against.
           * @param repo The Git Fusion Repo ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/git-fusion-repos/{repo}")
        CommandResponse deleteGitFusionRepo(
        @Path("server") String server, @Path("repo") String repo
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param repo The Git Fusion Repo ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/git-fusion-repos/{repo}")
        void deleteGitFusionRepo(
        @Path("server") String server, @Path("repo") String repo, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Updates values in the repository configuration.\nThis method will find all specified parameters and update each value for the specified repository&#39;s configuration file.
           * @param server The server ID that we execute this particular method against.
           * @param repo The Git Fusion Repo ID
           * @param body The new configuration
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/git-fusion-repos/{repo}")
        CommandResponse updateGitFusionRepo(
        @Path("server") String server, @Path("repo") String repo, @Body GitFusionRepoConfig body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param repo The Git Fusion Repo ID
           * @param body The new configuration
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/git-fusion-repos/{repo}")
        void updateGitFusionRepo(
        @Path("server") String server, @Path("repo") String repo, @Body GitFusionRepoConfig body, Callback<CommandResponse> cb
            );
    
        }
