package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.google.gson.annotations.SerializedName;




/**
 * A summary of depots in the system, with information provided by the `p4 depots` command.
 **/
@ApiModel(description = "A summary of depots in the system, with information provided by the `p4 depots` command.")
public class DepotsCommand   {
  
  @SerializedName("depot")
  private String depot = null;
  
  @SerializedName("map")
  private String map = null;
  
  @SerializedName("type")
  private String type = null;
  
  @SerializedName("streamDepth")
  private String streamDepth = null;
  
  @SerializedName("description")
  private String description = null;
  

  
  /**
   * The depot name.
   **/
  @ApiModelProperty(value = "The depot name.")
  public String getDepot() {
    return depot;
  }
  public void setDepot(String depot) {
    this.depot = depot;
  }

  
  /**
   * If the Type: is local, spec, or archive, set the map to point to the relative location of the depot subdirectory.\nThe map must contain the `...` wildcard; for example, a local depot new might have a Map: of `new/...`.\n\nIf the Type: is remote, set the map to point to a location in the remote depot's physical namespace, for example, `//depot/new/rel2/...`.\nThis directory will be the root of the local representation of the remote depot.
   **/
  @ApiModelProperty(value = "If the Type: is local, spec, or archive, set the map to point to the relative location of the depot subdirectory.\nThe map must contain the `...` wildcard; for example, a local depot new might have a Map: of `new/...`.\n\nIf the Type: is remote, set the map to point to a location in the remote depot's physical namespace, for example, `//depot/new/rel2/...`.\nThis directory will be the root of the local representation of the remote depot.")
  public String getMap() {
    return map;
  }
  public void setMap(String map) {
    this.map = map;
  }

  
  /**
   * `local`, `remote`, `spec`, `stream`, `unload`, `archive` or `tangent`.\n\nA local depot is writable, and is the default depot type.\nFiles reside in the server's root directory and are managed directly by the server.\n\nA stream depot is also writable, but contains streams, a type of branch that includes hierarchy and policy.\n\nA remote depot references files that reside on other servers, and cannot be written to.\n\nThe spec depot, if present, automatically archives edited forms.\n\nThe unload depot, if present, holds infrequently-used metadata (about old client workspaces and labels) that has been unloaded with the p4 unload command.\n\nAn archive depot is used in conjunction with the p4 archive and p4 restore commands to facilitate offline (or near-line) storage of infrequently-accessed revisions, typically large binaries.\n\nA tangent depot defines a read-only location that holds tangents created by the p4 fetch -t command.\nThe tangent depot named tangent is automatically created by p4 fetch -t if one does not already exist.
   **/
  @ApiModelProperty(value = "`local`, `remote`, `spec`, `stream`, `unload`, `archive` or `tangent`.\n\nA local depot is writable, and is the default depot type.\nFiles reside in the server's root directory and are managed directly by the server.\n\nA stream depot is also writable, but contains streams, a type of branch that includes hierarchy and policy.\n\nA remote depot references files that reside on other servers, and cannot be written to.\n\nThe spec depot, if present, automatically archives edited forms.\n\nThe unload depot, if present, holds infrequently-used metadata (about old client workspaces and labels) that has been unloaded with the p4 unload command.\n\nAn archive depot is used in conjunction with the p4 archive and p4 restore commands to facilitate offline (or near-line) storage of infrequently-accessed revisions, typically large binaries.\n\nA tangent depot defines a read-only location that holds tangents created by the p4 fetch -t command.\nThe tangent depot named tangent is automatically created by p4 fetch -t if one does not already exist.")
  public String getType() {
    return type;
  }
  public void setType(String type) {
    this.type = type;
  }

  
  /**
   * For stream depots, the optional depth to be used for stream paths in the depot, where depth specifies the number of slashes following the depot name of a stream. ]\n\nThis field is used when streams are being created.\nThe default is 1, matching the traditional stream name.\nYou cannot update this value once streams or archive data exist in a depot.
   **/
  @ApiModelProperty(value = "For stream depots, the optional depth to be used for stream paths in the depot, where depth specifies the number of slashes following the depot name of a stream. ]\n\nThis field is used when streams are being created.\nThe default is 1, matching the traditional stream name.\nYou cannot update this value once streams or archive data exist in a depot.")
  public String getStreamDepth() {
    return streamDepth;
  }
  public void setStreamDepth(String streamDepth) {
    this.streamDepth = streamDepth;
  }

  
  /**
   * A short description of the depot’s purpose. Optional.
   **/
  @ApiModelProperty(value = "A short description of the depot’s purpose. Optional.")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    DepotsCommand depotsCommand = (DepotsCommand) o;
    return Objects.equals(this.depot, depotsCommand.depot) &&
        Objects.equals(this.map, depotsCommand.map) &&
        Objects.equals(this.type, depotsCommand.type) &&
        Objects.equals(this.streamDepth, depotsCommand.streamDepth) &&
        Objects.equals(this.description, depotsCommand.description);
  }

  @Override
  public int hashCode() {
    return Objects.hash(depot, map, type, streamDepth, description);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class DepotsCommand {\n");
    
    sb.append("    depot: ").append(toIndentedString(depot)).append("\n");
    sb.append("    map: ").append(toIndentedString(map)).append("\n");
    sb.append("    type: ").append(toIndentedString(type)).append("\n");
    sb.append("    streamDepth: ").append(toIndentedString(streamDepth)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
