package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;

import com.google.gson.annotations.SerializedName;




/**
 * Defines a unique Git Fusion branch.
 **/
@ApiModel(description = "Defines a unique Git Fusion branch.")
public class GitFusionRepoBranchConfig   {
  
  @SerializedName("gitBranchId")
  private String gitBranchId = null;
  
  @SerializedName("gitBranchName")
  private String gitBranchName = null;
  
  @SerializedName("view")
  private List<String> view = new ArrayList<String>();
  
  @SerializedName("stream")
  private String stream = null;
  
  @SerializedName("readOnly")
  private String readOnly = null;
  

  
  /**
   * Alphanumeric ID for the git branch.\n_Do not change this value once this repo has been cloned_.
   **/
  @ApiModelProperty(value = "Alphanumeric ID for the git branch.\n_Do not change this value once this repo has been cloned_.")
  public String getGitBranchId() {
    return gitBranchId;
  }
  public void setGitBranchId(String gitBranchId) {
    this.gitBranchId = gitBranchId;
  }

  
  /**
   * Defines a name specified in a local repo for a Git branch.\n\nA valid Git branch name.\nDo not edit this value after you clone the repo.
   **/
  @ApiModelProperty(value = "Defines a name specified in a local repo for a Git branch.\n\nA valid Git branch name.\nDo not edit this value after you clone the repo.")
  public String getGitBranchName() {
    return gitBranchName;
  }
  public void setGitBranchName(String gitBranchName) {
    this.gitBranchName = gitBranchName;
  }

  
  /**
   * Defines a Perforce workspace view mapping that maps Perforce depot paths (left side) to Git work tree paths (right side).\n\nCorrectly formed mapping syntax; must not include any Perforce stream or spec depots, and all depot paths on the right side must match exactly across all branch definitions.\nYou can add and remove only certain types of Perforce branches from this view after you clone the repo.
   **/
  @ApiModelProperty(value = "Defines a Perforce workspace view mapping that maps Perforce depot paths (left side) to Git work tree paths (right side).\n\nCorrectly formed mapping syntax; must not include any Perforce stream or spec depots, and all depot paths on the right side must match exactly across all branch definitions.\nYou can add and remove only certain types of Perforce branches from this view after you clone the repo.")
  public List<String> getView() {
    return view;
  }
  public void setView(List<String> view) {
    this.view = view;
  }

  
  /**
   * Defines a Perforce stream that maps to the Git branch.\n\nProvide a stream name using the syntax //streamdepot/mystream.\nA Git Fusion branch can be defined as a view or a stream but not both.\nIf your branch is defined as stream, it can include only one stream.
   **/
  @ApiModelProperty(value = "Defines a Perforce stream that maps to the Git branch.\n\nProvide a stream name using the syntax //streamdepot/mystream.\nA Git Fusion branch can be defined as a view or a stream but not both.\nIf your branch is defined as stream, it can include only one stream.")
  public String getStream() {
    return stream;
  }
  public void setStream(String stream) {
    this.stream = stream;
  }

  
  /**
   * Prohibit git pushes that introduce commits to the branch.
   **/
  @ApiModelProperty(value = "Prohibit git pushes that introduce commits to the branch.")
  public String getReadOnly() {
    return readOnly;
  }
  public void setReadOnly(String readOnly) {
    this.readOnly = readOnly;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    GitFusionRepoBranchConfig gitFusionRepoBranchConfig = (GitFusionRepoBranchConfig) o;
    return Objects.equals(this.gitBranchId, gitFusionRepoBranchConfig.gitBranchId) &&
        Objects.equals(this.gitBranchName, gitFusionRepoBranchConfig.gitBranchName) &&
        Objects.equals(this.view, gitFusionRepoBranchConfig.view) &&
        Objects.equals(this.stream, gitFusionRepoBranchConfig.stream) &&
        Objects.equals(this.readOnly, gitFusionRepoBranchConfig.readOnly);
  }

  @Override
  public int hashCode() {
    return Objects.hash(gitBranchId, gitBranchName, view, stream, readOnly);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class GitFusionRepoBranchConfig {\n");
    
    sb.append("    gitBranchId: ").append(toIndentedString(gitBranchId)).append("\n");
    sb.append("    gitBranchName: ").append(toIndentedString(gitBranchName)).append("\n");
    sb.append("    view: ").append(toIndentedString(view)).append("\n");
    sb.append("    stream: ").append(toIndentedString(stream)).append("\n");
    sb.append("    readOnly: ").append(toIndentedString(readOnly)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
