package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;

import com.google.gson.annotations.SerializedName;




/**
 * Add or delete users from a group, or set the maxresults, maxscanrows, maxlocktime, and timeout limits for the members of a group.
 **/
@ApiModel(description = "Add or delete users from a group, or set the maxresults, maxscanrows, maxlocktime, and timeout limits for the members of a group.")
public class GroupCommand   {
  
  @SerializedName("group")
  private String group = null;
  
  @SerializedName("maxResults")
  private String maxResults = null;
  
  @SerializedName("maxScanRows")
  private String maxScanRows = null;
  
  @SerializedName("maxLockTime")
  private String maxLockTime = null;
  
  @SerializedName("maxOpenFiles")
  private String maxOpenFiles = null;
  
  @SerializedName("timeout")
  private String timeout = null;
  
  @SerializedName("passwordTimeout")
  private String passwordTimeout = null;
  
  @SerializedName("ldapConfig")
  private String ldapConfig = null;
  
  @SerializedName("ldapSearchQuery")
  private String ldapSearchQuery = null;
  
  @SerializedName("ldapUserAttribute")
  private String ldapUserAttribute = null;
  
  @SerializedName("subgroups")
  private List<String> subgroups = new ArrayList<String>();
  
  @SerializedName("owners")
  private List<String> owners = new ArrayList<String>();
  
  @SerializedName("users")
  private List<String> users = new ArrayList<String>();
  

  
  /**
   * The name of the group, as entered on the command line.
   **/
  @ApiModelProperty(value = "The name of the group, as entered on the command line.")
  public String getGroup() {
    return group;
  }
  public void setGroup(String group) {
    this.group = group;
  }

  
  /**
   * The maximum number of results that members of this group can access from the service from a single command.\nThe default value is `unset`.
   **/
  @ApiModelProperty(value = "The maximum number of results that members of this group can access from the service from a single command.\nThe default value is `unset`.")
  public String getMaxResults() {
    return maxResults;
  }
  public void setMaxResults(String maxResults) {
    this.maxResults = maxResults;
  }

  
  /**
   * The maximum number of rows that members of this group can scan from the service from a single command.\nThe default value is `unset`.
   **/
  @ApiModelProperty(value = "The maximum number of rows that members of this group can scan from the service from a single command.\nThe default value is `unset`.")
  public String getMaxScanRows() {
    return maxScanRows;
  }
  public void setMaxScanRows(String maxScanRows) {
    this.maxScanRows = maxScanRows;
  }

  
  /**
   * The maximum length of time (in milliseconds) that any one operation can lock any database table when scanning data.\nThe default value is `unset`.
   **/
  @ApiModelProperty(value = "The maximum length of time (in milliseconds) that any one operation can lock any database table when scanning data.\nThe default value is `unset`.")
  public String getMaxLockTime() {
    return maxLockTime;
  }
  public void setMaxLockTime(String maxLockTime) {
    this.maxLockTime = maxLockTime;
  }

  
  /**
   * The maximum number of files that a member of a group can open using a single command.
   **/
  @ApiModelProperty(value = "The maximum number of files that a member of a group can open using a single command.")
  public String getMaxOpenFiles() {
    return maxOpenFiles;
  }
  public void setMaxOpenFiles(String maxOpenFiles) {
    this.maxOpenFiles = maxOpenFiles;
  }

  
  /**
   * The duration (in seconds) of the validity of a session ticket created by p4 login.\nThe default value is 43,200 seconds (12 hours).\nTo create a ticket that does not expire, set the Timeout: field to `unlimited`.
   **/
  @ApiModelProperty(value = "The duration (in seconds) of the validity of a session ticket created by p4 login.\nThe default value is 43,200 seconds (12 hours).\nTo create a ticket that does not expire, set the Timeout: field to `unlimited`.")
  public String getTimeout() {
    return timeout;
  }
  public void setTimeout(String timeout) {
    this.timeout = timeout;
  }

  
  /**
   * The length of time (in seconds) for which passwords for users in this group remain valid.\nTo disable password aging, use a value of unset.
   **/
  @ApiModelProperty(value = "The length of time (in seconds) for which passwords for users in this group remain valid.\nTo disable password aging, use a value of unset.")
  public String getPasswordTimeout() {
    return passwordTimeout;
  }
  public void setPasswordTimeout(String passwordTimeout) {
    this.passwordTimeout = passwordTimeout;
  }

  
  /**
   * The LDAP configuration to use when populating the group’s user list from an LDAP query.
   **/
  @ApiModelProperty(value = "The LDAP configuration to use when populating the group’s user list from an LDAP query.")
  public String getLdapConfig() {
    return ldapConfig;
  }
  public void setLdapConfig(String ldapConfig) {
    this.ldapConfig = ldapConfig;
  }

  
  /**
   * The LDAP query used to identify the members of the group.
   **/
  @ApiModelProperty(value = "The LDAP query used to identify the members of the group.")
  public String getLdapSearchQuery() {
    return ldapSearchQuery;
  }
  public void setLdapSearchQuery(String ldapSearchQuery) {
    this.ldapSearchQuery = ldapSearchQuery;
  }

  
  /**
   * The LDAP attribute that represents the user’s username.
   **/
  @ApiModelProperty(value = "The LDAP attribute that represents the user’s username.")
  public String getLdapUserAttribute() {
    return ldapUserAttribute;
  }
  public void setLdapUserAttribute(String ldapUserAttribute) {
    this.ldapUserAttribute = ldapUserAttribute;
  }

  
  /**
   * Names of other Perforce groups.\n\nTo add all users in a previously defined group to the group you’re presently working with, include the group name in the Subgroups: field of the p4 group form.\nNote that user and group names occupy separate namespaces, and thus, groups and users can have the same names.\n\nEvery member of any previously defined group you list in the Subgroups: field will be a member of the group you’re now defining.
   **/
  @ApiModelProperty(value = "Names of other Perforce groups.\n\nTo add all users in a previously defined group to the group you’re presently working with, include the group name in the Subgroups: field of the p4 group form.\nNote that user and group names occupy separate namespaces, and thus, groups and users can have the same names.\n\nEvery member of any previously defined group you list in the Subgroups: field will be a member of the group you’re now defining.")
  public List<String> getSubgroups() {
    return subgroups;
  }
  public void setSubgroups(List<String> subgroups) {
    this.subgroups = subgroups;
  }

  
  /**
   * Names of other Perforce users.\n\n  Group owners without super access are permitted to administer this group, provided that they use the -a option.\n\n  Group owners are not necessarily members of a group; if a group owner is to be a member of the group, the userid must also be added to the Users: field.\n\n  The specified owner does not have to be a Perforce user.\n  You might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.
   **/
  @ApiModelProperty(value = "Names of other Perforce users.\n\n  Group owners without super access are permitted to administer this group, provided that they use the -a option.\n\n  Group owners are not necessarily members of a group; if a group owner is to be a member of the group, the userid must also be added to the Users: field.\n\n  The specified owner does not have to be a Perforce user.\n  You might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.")
  public List<String> getOwners() {
    return owners;
  }
  public void setOwners(List<String> owners) {
    this.owners = owners;
  }

  
  /**
   * The Perforce usernames of the group members.
   **/
  @ApiModelProperty(value = "The Perforce usernames of the group members.")
  public List<String> getUsers() {
    return users;
  }
  public void setUsers(List<String> users) {
    this.users = users;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    GroupCommand groupCommand = (GroupCommand) o;
    return Objects.equals(this.group, groupCommand.group) &&
        Objects.equals(this.maxResults, groupCommand.maxResults) &&
        Objects.equals(this.maxScanRows, groupCommand.maxScanRows) &&
        Objects.equals(this.maxLockTime, groupCommand.maxLockTime) &&
        Objects.equals(this.maxOpenFiles, groupCommand.maxOpenFiles) &&
        Objects.equals(this.timeout, groupCommand.timeout) &&
        Objects.equals(this.passwordTimeout, groupCommand.passwordTimeout) &&
        Objects.equals(this.ldapConfig, groupCommand.ldapConfig) &&
        Objects.equals(this.ldapSearchQuery, groupCommand.ldapSearchQuery) &&
        Objects.equals(this.ldapUserAttribute, groupCommand.ldapUserAttribute) &&
        Objects.equals(this.subgroups, groupCommand.subgroups) &&
        Objects.equals(this.owners, groupCommand.owners) &&
        Objects.equals(this.users, groupCommand.users);
  }

  @Override
  public int hashCode() {
    return Objects.hash(group, maxResults, maxScanRows, maxLockTime, maxOpenFiles, timeout, passwordTimeout, ldapConfig, ldapSearchQuery, ldapUserAttribute, subgroups, owners, users);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class GroupCommand {\n");
    
    sb.append("    group: ").append(toIndentedString(group)).append("\n");
    sb.append("    maxResults: ").append(toIndentedString(maxResults)).append("\n");
    sb.append("    maxScanRows: ").append(toIndentedString(maxScanRows)).append("\n");
    sb.append("    maxLockTime: ").append(toIndentedString(maxLockTime)).append("\n");
    sb.append("    maxOpenFiles: ").append(toIndentedString(maxOpenFiles)).append("\n");
    sb.append("    timeout: ").append(toIndentedString(timeout)).append("\n");
    sb.append("    passwordTimeout: ").append(toIndentedString(passwordTimeout)).append("\n");
    sb.append("    ldapConfig: ").append(toIndentedString(ldapConfig)).append("\n");
    sb.append("    ldapSearchQuery: ").append(toIndentedString(ldapSearchQuery)).append("\n");
    sb.append("    ldapUserAttribute: ").append(toIndentedString(ldapUserAttribute)).append("\n");
    sb.append("    subgroups: ").append(toIndentedString(subgroups)).append("\n");
    sb.append("    owners: ").append(toIndentedString(owners)).append("\n");
    sb.append("    users: ").append(toIndentedString(users)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
