package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * A label specification.\n\nLabels can be either automatic or static.\nAutomatic labels refer to the revisions provided in the View: and Revision: fields.\nStatic labels refer only to those specific revisions tagged by the label by means of either the p4 labelsync or p4 tag commands.
 **/
@ApiModel(description = "A label specification.\n\nLabels can be either automatic or static.\nAutomatic labels refer to the revisions provided in the View: and Revision: fields.\nStatic labels refer only to those specific revisions tagged by the label by means of either the p4 labelsync or p4 tag commands.")
public class LabelCommand   {
  
  @SerializedName("label")
  private String label = null;
  
  @SerializedName("owner")
  private String owner = null;
  
  @SerializedName("update")
  private Date update = null;
  
  @SerializedName("access")
  private Date access = null;
  
  @SerializedName("description")
  private String description = null;
  
  @SerializedName("options")
  private String options = null;
  
  @SerializedName("revision")
  private String revision = null;
  
  @SerializedName("view")
  private List<String> view = new ArrayList<String>();
  
  @SerializedName("serverID")
  private String serverID = null;
  

  
  /**
   * The label name.
   **/
  @ApiModelProperty(value = "The label name.")
  public String getLabel() {
    return label;
  }
  public void setLabel(String label) {
    this.label = label;
  }

  
  /**
   * The label’s owner.\nBy default, the user who created the label.\nOnly the owner of a label can update which files are tagged with the label.\n\nThe specified owner does not have to be a Perforce user.\nYou might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.
   **/
  @ApiModelProperty(value = "The label’s owner.\nBy default, the user who created the label.\nOnly the owner of a label can update which files are tagged with the label.\n\nThe specified owner does not have to be a Perforce user.\nYou might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.")
  public String getOwner() {
    return owner;
  }
  public void setOwner(String owner) {
    this.owner = owner;
  }

  
  /**
   * The date the label specification was last modified.
   **/
  @ApiModelProperty(value = "The date the label specification was last modified.")
  public Date getUpdate() {
    return update;
  }
  public void setUpdate(Date update) {
    this.update = update;
  }

  
  /**
   * The date and time the label was last accessed, either by running p4 labelsync on the label, or by otherwise referring to a file with the label revision specifier @label.\n(Note: Reloading a label with p4 reload does not affect the access time.)
   **/
  @ApiModelProperty(value = "The date and time the label was last accessed, either by running p4 labelsync on the label, or by otherwise referring to a file with the label revision specifier @label.\n(Note: Reloading a label with p4 reload does not affect the access time.)")
  public Date getAccess() {
    return access;
  }
  public void setAccess(Date access) {
    this.access = access;
  }

  
  /**
   * An optional description of the label’s purpose.
   **/
  @ApiModelProperty(value = "An optional description of the label’s purpose.")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }

  
  /**
   * Options to control behavior and storage location of labels.\n\n- locked or unlocked: If the label is locked, the list of files tagged with the label cannot be changed with p4 labelsync.\n\n- autoreload or noautoreload. For static labels, if noautoreload is set, the label is stored in db.label, and if autoreload is set, it is stored in the unload depot. This option is ignored for automatic labels. Storing labels in the unload depot can improve performance on sites that make extremely heavy use of labels.
   **/
  @ApiModelProperty(value = "Options to control behavior and storage location of labels.\n\n- locked or unlocked: If the label is locked, the list of files tagged with the label cannot be changed with p4 labelsync.\n\n- autoreload or noautoreload. For static labels, if noautoreload is set, the label is stored in db.label, and if autoreload is set, it is stored in the unload depot. This option is ignored for automatic labels. Storing labels in the unload depot can improve performance on sites that make extremely heavy use of labels.")
  public String getOptions() {
    return options;
  }
  public void setOptions(String options) {
    this.options = options;
  }

  
  /**
   * An optional revision specification for an automatic label.\n\nIf you use the # character to specify a revision number, you must use quotes around it in order to ensure that the # is parsed as a revision specifier, and not as a comment field in the form.
   **/
  @ApiModelProperty(value = "An optional revision specification for an automatic label.\n\nIf you use the # character to specify a revision number, you must use quotes around it in order to ensure that the # is parsed as a revision specifier, and not as a comment field in the form.")
  public String getRevision() {
    return revision;
  }
  public void setRevision(String revision) {
    this.revision = revision;
  }

  
  /**
   * A list of depot files that can be tagged with this label.\nNo files are actually tagged until `p4 labelsync` is invoked.\n\nUnlike client views or branch views, which map one set of files to another, label views consist of a simple list of depot files.
   **/
  @ApiModelProperty(value = "A list of depot files that can be tagged with this label.\nNo files are actually tagged until `p4 labelsync` is invoked.\n\nUnlike client views or branch views, which map one set of files to another, label views consist of a simple list of depot files.")
  public List<String> getView() {
    return view;
  }
  public void setView(List<String> view) {
    this.view = view;
  }

  
  /**
   * If set, restricts usage of the label to the named server.\nIf unset, this label may be used on any server.
   **/
  @ApiModelProperty(value = "If set, restricts usage of the label to the named server.\nIf unset, this label may be used on any server.")
  public String getServerID() {
    return serverID;
  }
  public void setServerID(String serverID) {
    this.serverID = serverID;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    LabelCommand labelCommand = (LabelCommand) o;
    return Objects.equals(this.label, labelCommand.label) &&
        Objects.equals(this.owner, labelCommand.owner) &&
        Objects.equals(this.update, labelCommand.update) &&
        Objects.equals(this.access, labelCommand.access) &&
        Objects.equals(this.description, labelCommand.description) &&
        Objects.equals(this.options, labelCommand.options) &&
        Objects.equals(this.revision, labelCommand.revision) &&
        Objects.equals(this.view, labelCommand.view) &&
        Objects.equals(this.serverID, labelCommand.serverID);
  }

  @Override
  public int hashCode() {
    return Objects.hash(label, owner, update, access, description, options, revision, view, serverID);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class LabelCommand {\n");
    
    sb.append("    label: ").append(toIndentedString(label)).append("\n");
    sb.append("    owner: ").append(toIndentedString(owner)).append("\n");
    sb.append("    update: ").append(toIndentedString(update)).append("\n");
    sb.append("    access: ").append(toIndentedString(access)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    options: ").append(toIndentedString(options)).append("\n");
    sb.append("    revision: ").append(toIndentedString(revision)).append("\n");
    sb.append("    view: ").append(toIndentedString(view)).append("\n");
    sb.append("    serverID: ").append(toIndentedString(serverID)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
